Pegasus Workflow Management System Python API
=============================================

This package contains the Python APIs for Pegasus WMS, including:

1. The DAX API (Versions 2 and 3)
2. The PDAX API (Version 2)
3. The monitoring API
4. The Stampede database API
5. The Pegasus statistics API
6. The Pegasus plots API
7. Misc. Pegasus utilities
8. The pegasus service, including the ensemble manager and dashboard

